@@ -14,6 +14,7 @@ from cloudfs_paths import rest_endpoints, ExistValues, VersionConflictValue, Res
 
 # more detailed debugging info, including redirects, but without any filtering. RIP terminal.
 debug = False
+cloudfs_version = '0.81.0'
 
 if debug:
     import logging
@@ -870,7 +871,7 @@ class CloudFSConnection(object):
         if oauth:
             headers['Content-Type'] = 'application/x-www-form-urlencoded; charset="utf-8"'
         headers['Date'] = datetime.datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')
-        headers['User-Agent'] = 'CloudFSPythonSDK/0.80.2'
+        headers['User-Agent'] = 'CloudFSPythonSDK/{}/{}'.format(cloudfs_version, self.client_id)
 
         return headers
 
